@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -35,10 +33,9 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.bigquery_reservation_v1.services.reservation_service import pagers
 from google.cloud.bigquery_reservation_v1.types import reservation
 from google.cloud.bigquery_reservation_v1.types import reservation as gcbr_reservation
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
-
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 from .transports.base import ReservationServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ReservationServiceGrpcTransport
 from .transports.grpc_asyncio import ReservationServiceGrpcAsyncIOTransport
@@ -61,7 +58,7 @@ class ReservationServiceClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[ReservationServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -101,7 +98,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -135,7 +133,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -152,7 +151,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -171,10 +170,11 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @property
     def transport(self) -> ReservationServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            ReservationServiceTransport: The transport used by the client instance.
+            ReservationServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
@@ -182,7 +182,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
     def assignment_path(
         project: str, location: str, reservation: str, assignment: str,
     ) -> str:
-        """Return a fully-qualified assignment string."""
+        """Returns a fully-qualified assignment string."""
         return "projects/{project}/locations/{location}/reservations/{reservation}/assignments/{assignment}".format(
             project=project,
             location=location,
@@ -192,7 +192,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def parse_assignment_path(path: str) -> Dict[str, str]:
-        """Parse a assignment path into its component segments."""
+        """Parses a assignment path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/reservations/(?P<reservation>.+?)/assignments/(?P<assignment>.+?)$",
             path,
@@ -201,14 +201,14 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def bi_reservation_path(project: str, location: str,) -> str:
-        """Return a fully-qualified bi_reservation string."""
+        """Returns a fully-qualified bi_reservation string."""
         return "projects/{project}/locations/{location}/bireservation".format(
             project=project, location=location,
         )
 
     @staticmethod
     def parse_bi_reservation_path(path: str) -> Dict[str, str]:
-        """Parse a bi_reservation path into its component segments."""
+        """Parses a bi_reservation path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/bireservation$",
             path,
@@ -219,14 +219,14 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
     def capacity_commitment_path(
         project: str, location: str, capacity_commitment: str,
     ) -> str:
-        """Return a fully-qualified capacity_commitment string."""
+        """Returns a fully-qualified capacity_commitment string."""
         return "projects/{project}/locations/{location}/capacityCommitments/{capacity_commitment}".format(
             project=project, location=location, capacity_commitment=capacity_commitment,
         )
 
     @staticmethod
     def parse_capacity_commitment_path(path: str) -> Dict[str, str]:
-        """Parse a capacity_commitment path into its component segments."""
+        """Parses a capacity_commitment path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/capacityCommitments/(?P<capacity_commitment>.+?)$",
             path,
@@ -235,14 +235,14 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def reservation_path(project: str, location: str, reservation: str,) -> str:
-        """Return a fully-qualified reservation string."""
+        """Returns a fully-qualified reservation string."""
         return "projects/{project}/locations/{location}/reservations/{reservation}".format(
             project=project, location=location, reservation=reservation,
         )
 
     @staticmethod
     def parse_reservation_path(path: str) -> Dict[str, str]:
-        """Parse a reservation path into its component segments."""
+        """Parses a reservation path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/reservations/(?P<reservation>.+?)$",
             path,
@@ -251,7 +251,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -264,7 +264,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -275,7 +275,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -286,7 +286,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -297,7 +297,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -311,12 +311,12 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ReservationServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the reservation service client.
+        """Instantiates the reservation service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -371,9 +371,10 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -385,12 +386,14 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -405,8 +408,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -461,7 +464,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``reservation_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -490,10 +492,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, gcbr_reservation.CreateReservationRequest):
             request = gcbr_reservation.CreateReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if reservation is not None:
@@ -540,7 +540,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -572,10 +571,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.ListReservationsRequest):
             request = reservation.ListReservationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -624,7 +621,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -653,10 +649,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.GetReservationRequest):
             request = reservation.GetReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -701,7 +695,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -724,10 +717,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.DeleteReservationRequest):
             request = reservation.DeleteReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -751,7 +742,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         request: gcbr_reservation.UpdateReservationRequest = None,
         *,
         reservation: gcbr_reservation.Reservation = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -774,7 +765,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -803,10 +793,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, gcbr_reservation.UpdateReservationRequest):
             request = gcbr_reservation.UpdateReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if reservation is not None:
                 request.reservation = reservation
             if update_mask is not None:
@@ -860,7 +848,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``capacity_commitment`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -901,10 +888,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.CreateCapacityCommitmentRequest):
             request = reservation.CreateCapacityCommitmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if capacity_commitment is not None:
@@ -951,7 +936,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -983,10 +967,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.ListCapacityCommitmentsRequest):
             request = reservation.ListCapacityCommitmentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1037,7 +1019,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1078,10 +1059,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.GetCapacityCommitmentRequest):
             request = reservation.GetCapacityCommitmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1126,7 +1105,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1149,10 +1127,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.DeleteCapacityCommitmentRequest):
             request = reservation.DeleteCapacityCommitmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1178,7 +1154,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         request: reservation.UpdateCapacityCommitmentRequest = None,
         *,
         capacity_commitment: reservation.CapacityCommitment = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1210,7 +1186,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1251,10 +1226,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.UpdateCapacityCommitmentRequest):
             request = reservation.UpdateCapacityCommitmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if capacity_commitment is not None:
                 request.capacity_commitment = capacity_commitment
             if update_mask is not None:
@@ -1318,7 +1291,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``slot_count`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1347,10 +1319,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.SplitCapacityCommitmentRequest):
             request = reservation.SplitCapacityCommitmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if slot_count is not None:
@@ -1418,7 +1388,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``capacity_commitment_ids`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1459,15 +1428,12 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.MergeCapacityCommitmentsRequest):
             request = reservation.MergeCapacityCommitmentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
-
-            if capacity_commitment_ids:
-                request.capacity_commitment_ids.extend(capacity_commitment_ids)
+            if capacity_commitment_ids is not None:
+                request.capacity_commitment_ids = capacity_commitment_ids
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1549,7 +1515,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``assignment`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1579,10 +1544,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.CreateAssignmentRequest):
             request = reservation.CreateAssignmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if assignment is not None:
@@ -1652,7 +1615,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1684,10 +1646,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.ListAssignmentsRequest):
             request = reservation.ListAssignmentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1752,7 +1712,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1775,10 +1734,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.DeleteAssignmentRequest):
             request = reservation.DeleteAssignmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1860,7 +1817,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``query`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1892,10 +1848,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.SearchAssignmentsRequest):
             request = reservation.SearchAssignmentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if query is not None:
@@ -1963,7 +1917,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``destination_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1993,10 +1946,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.MoveAssignmentRequest):
             request = reservation.MoveAssignmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if destination_id is not None:
@@ -2041,7 +1992,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2068,10 +2018,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.GetBiReservationRequest):
             request = reservation.GetBiReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -2096,7 +2044,7 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         request: reservation.UpdateBiReservationRequest = None,
         *,
         bi_reservation: reservation.BiReservation = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -2126,7 +2074,6 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2153,10 +2100,8 @@ class ReservationServiceClient(metaclass=ReservationServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, reservation.UpdateBiReservationRequest):
             request = reservation.UpdateBiReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if bi_reservation is not None:
                 request.bi_reservation = bi_reservation
             if update_mask is not None:
