@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,21 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.bigquery_reservation_v1.types import reservation
 from google.cloud.bigquery_reservation_v1.types import reservation as gcbr_reservation
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -39,6 +39,15 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
 
 class ReservationServiceTransport(abc.ABC):
     """Abstract transport class for ReservationService."""
@@ -48,21 +57,25 @@ class ReservationServiceTransport(abc.ABC):
         "https://www.googleapis.com/auth/cloud-platform",
     )
 
+    DEFAULT_HOST: str = "bigqueryreservation.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "bigqueryreservation.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -71,42 +84,77 @@ class ReservationServiceTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
+        # Save the scopes.
+        self._scopes = scopes
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials is service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
+    # TODO(busunkim): This method is in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-auth is increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
 
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
@@ -121,8 +169,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -134,8 +184,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -147,8 +199,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -168,8 +222,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -181,8 +237,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -194,8 +252,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -225,8 +285,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -238,8 +300,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -251,8 +315,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -267,8 +333,10 @@ class ReservationServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -283,22 +351,20 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def create_reservation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [gcbr_reservation.CreateReservationRequest],
-        typing.Union[
-            gcbr_reservation.Reservation, typing.Awaitable[gcbr_reservation.Reservation]
-        ],
+        Union[gcbr_reservation.Reservation, Awaitable[gcbr_reservation.Reservation]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_reservations(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.ListReservationsRequest],
-        typing.Union[
+        Union[
             reservation.ListReservationsResponse,
-            typing.Awaitable[reservation.ListReservationsResponse],
+            Awaitable[reservation.ListReservationsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -306,42 +372,37 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def get_reservation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.GetReservationRequest],
-        typing.Union[
-            reservation.Reservation, typing.Awaitable[reservation.Reservation]
-        ],
+        Union[reservation.Reservation, Awaitable[reservation.Reservation]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_reservation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.DeleteReservationRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def update_reservation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [gcbr_reservation.UpdateReservationRequest],
-        typing.Union[
-            gcbr_reservation.Reservation, typing.Awaitable[gcbr_reservation.Reservation]
-        ],
+        Union[gcbr_reservation.Reservation, Awaitable[gcbr_reservation.Reservation]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_capacity_commitment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.CreateCapacityCommitmentRequest],
-        typing.Union[
-            reservation.CapacityCommitment,
-            typing.Awaitable[reservation.CapacityCommitment],
+        Union[
+            reservation.CapacityCommitment, Awaitable[reservation.CapacityCommitment]
         ],
     ]:
         raise NotImplementedError()
@@ -349,11 +410,11 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def list_capacity_commitments(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.ListCapacityCommitmentsRequest],
-        typing.Union[
+        Union[
             reservation.ListCapacityCommitmentsResponse,
-            typing.Awaitable[reservation.ListCapacityCommitmentsResponse],
+            Awaitable[reservation.ListCapacityCommitmentsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -361,11 +422,10 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def get_capacity_commitment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.GetCapacityCommitmentRequest],
-        typing.Union[
-            reservation.CapacityCommitment,
-            typing.Awaitable[reservation.CapacityCommitment],
+        Union[
+            reservation.CapacityCommitment, Awaitable[reservation.CapacityCommitment]
         ],
     ]:
         raise NotImplementedError()
@@ -373,20 +433,19 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def delete_capacity_commitment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.DeleteCapacityCommitmentRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def update_capacity_commitment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.UpdateCapacityCommitmentRequest],
-        typing.Union[
-            reservation.CapacityCommitment,
-            typing.Awaitable[reservation.CapacityCommitment],
+        Union[
+            reservation.CapacityCommitment, Awaitable[reservation.CapacityCommitment]
         ],
     ]:
         raise NotImplementedError()
@@ -394,11 +453,11 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def split_capacity_commitment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.SplitCapacityCommitmentRequest],
-        typing.Union[
+        Union[
             reservation.SplitCapacityCommitmentResponse,
-            typing.Awaitable[reservation.SplitCapacityCommitmentResponse],
+            Awaitable[reservation.SplitCapacityCommitmentResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -406,11 +465,10 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def merge_capacity_commitments(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.MergeCapacityCommitmentsRequest],
-        typing.Union[
-            reservation.CapacityCommitment,
-            typing.Awaitable[reservation.CapacityCommitment],
+        Union[
+            reservation.CapacityCommitment, Awaitable[reservation.CapacityCommitment]
         ],
     ]:
         raise NotImplementedError()
@@ -418,20 +476,20 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def create_assignment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.CreateAssignmentRequest],
-        typing.Union[reservation.Assignment, typing.Awaitable[reservation.Assignment]],
+        Union[reservation.Assignment, Awaitable[reservation.Assignment]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_assignments(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.ListAssignmentsRequest],
-        typing.Union[
+        Union[
             reservation.ListAssignmentsResponse,
-            typing.Awaitable[reservation.ListAssignmentsResponse],
+            Awaitable[reservation.ListAssignmentsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -439,20 +497,20 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def delete_assignment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.DeleteAssignmentRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def search_assignments(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.SearchAssignmentsRequest],
-        typing.Union[
+        Union[
             reservation.SearchAssignmentsResponse,
-            typing.Awaitable[reservation.SearchAssignmentsResponse],
+            Awaitable[reservation.SearchAssignmentsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -460,31 +518,27 @@ class ReservationServiceTransport(abc.ABC):
     @property
     def move_assignment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.MoveAssignmentRequest],
-        typing.Union[reservation.Assignment, typing.Awaitable[reservation.Assignment]],
+        Union[reservation.Assignment, Awaitable[reservation.Assignment]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_bi_reservation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.GetBiReservationRequest],
-        typing.Union[
-            reservation.BiReservation, typing.Awaitable[reservation.BiReservation]
-        ],
+        Union[reservation.BiReservation, Awaitable[reservation.BiReservation]],
     ]:
         raise NotImplementedError()
 
     @property
     def update_bi_reservation(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [reservation.UpdateBiReservationRequest],
-        typing.Union[
-            reservation.BiReservation, typing.Awaitable[reservation.BiReservation]
-        ],
+        Union[reservation.BiReservation, Awaitable[reservation.BiReservation]],
     ]:
         raise NotImplementedError()
 
